@@ -5,7 +5,7 @@
 #       University of Pavia - Italy                           #
 #       www.labmedinfo.org                                    #
 #                                                             #
-#   $Id: dtw.R 83 2008-01-04 00:25:00Z tonig $
+#   $Id: dtw.R 126 2008-05-29 12:44:37Z tonig $
 #                                                             #
 ###############################################################
 
@@ -22,6 +22,7 @@ function(x, y=NULL,
          window.type="none",
          keep.internals=FALSE,
          distance.only=FALSE,
+         partial=FALSE,
          ... ) {
 
   lm <- NULL;
@@ -30,14 +31,16 @@ function(x, y=NULL,
   
   ## if matrix given
   if(is.null(y)) {
-    if(!is.matrix(x)) 
-      stop("Single argument requires a global cost matrix");
+      if(!is.matrix(x)) 
+        stop("Single argument requires a global cost matrix");
     
-    lm <- x;
+      lm <- x;
   } else {
-    ## two ts. given TODO handle multivariate
-    ## as.numeric handles ts, but not multivariates
-    lm <- proxy::dist(x,y,method=dist.method);
+      ## two timeseries or vectors given
+      ## as.matrix coerces ts or mts to matrices
+      x <- as.matrix(x);
+      y <- as.matrix(y);
+      lm <- proxy::dist(x,y,method=dist.method);
   }
 
 
@@ -58,9 +61,12 @@ function(x, y=NULL,
                           window.function=wfun, ...);
 
 
-  
-  jmin <- m;
-
+  ## for complete alignment
+  gcm$jmin <- m;
+  ## for partial alignment
+  if (partial) {
+    gcm$jmin <- which.min(gcm$costMatrix[n,]);
+  }
 
   ## remember size
   gcm$N <- n;
@@ -70,7 +76,7 @@ function(x, y=NULL,
   gcm$call <- match.call();
 
   ## result: distance (add to existing list gcm?)
-  gcm$distance <- gcm$costMatrix[n,jmin];
+  gcm$distance <- gcm$costMatrix[n,gcm$jmin];
 
   ## alignment valid?
   if(is.na(gcm$distance))
@@ -79,7 +85,7 @@ function(x, y=NULL,
   
   if(!distance.only) {
     ## perform the backtrack
-    mapping <- backtrack(jmin,gcm);
+    mapping <- backtrack(gcm);
 
     ## append to existing list gcm, for now
     ## perhaps replace by attr()
